@@ -40,24 +40,17 @@ class State:
     # Iteration in which the state was introduced.
     iteration = attr.ib(type=int, default=0)
     # States added in the given iteration.
-    unresolved_dependencies = attr.ib(
-        default=attr.Factory(dict)
-    )  # type: Dict[str, Dict[int, Tuple[str, str, str]]]
-    resolved_dependencies = attr.ib(
-        default=attr.Factory(dict)
-    )  # type: Dict[str, Tuple[str, str, str]]
-    advised_runtime_environment = attr.ib(
-        type=Optional[RuntimeEnvironment], kw_only=True, default=None
-    )
-    justification = attr.ib(
-        type=List[Dict[str, str]], default=attr.Factory(list), kw_only=True
-    )
-    _parent = attr.ib(default=None, type=weakref)
+    unresolved_dependencies = attr.ib(default=attr.Factory(dict))  # type: Dict[str, Dict[int, Tuple[str, str, str]]]
+    resolved_dependencies = attr.ib(default=attr.Factory(dict))  # type: Dict[str, Tuple[str, str, str]]
+    _parent = attr.ib(default=None)  # type: weakref.ReferenceType['State']
+    advised_runtime_environment = attr.ib(type=Optional[RuntimeEnvironment], kw_only=True, default=None)
+    justification = attr.ib(type=List[Dict[str, str]], default=attr.Factory(list), kw_only=True)
 
     _EPSILON = 0.1
 
     @property
-    def parent(self) -> Optional["State"]:
+    def parent(self):
+        # type:('State') -> Optional['State']
         """Retrieve parent to this state.
 
         If None the state is top level state or parent is no longer maintained. Note the return
@@ -69,23 +62,19 @@ class State:
         return None
 
     @classmethod
-    def from_direct_dependencies(
-        cls, direct_dependencies: Dict[str, List[PackageVersion]]
-    ) -> "State":
+    def from_direct_dependencies(cls, direct_dependencies: Dict[str, List[PackageVersion]]) -> "State":
         """Create an initial state out of direct dependencies."""
-        unresolved_dependencies = {}
+        unresolved_dependencies = {}  # type: Dict[str, Dict[int, Tuple[str, str, str]]]
 
         for dependency_name, dependency_versions in direct_dependencies.items():
             unresolved_dependencies[dependency_name] = {}
             for dependency_version in dependency_versions:
                 dependency_tuple = dependency_version.to_tuple()
-                unresolved_dependencies[dependency_name][
-                    hash(dependency_tuple)
-                ] = dependency_tuple
+                unresolved_dependencies[dependency_name][hash(dependency_tuple)] = dependency_tuple
 
         return cls(unresolved_dependencies=unresolved_dependencies)
 
-    def __lt__(self, other) -> bool:
+    def __lt__(self, other: "State") -> bool:
         """Compare two objects, comparision protocol used in the beam."""
         return self.score < other.score
 
@@ -118,18 +107,12 @@ class State:
         if package_tuple[0] not in self.unresolved_dependencies:
             self.unresolved_dependencies[package_tuple[0]] = {}
 
-        self.unresolved_dependencies[package_tuple[0]][
-            hash(package_tuple)
-        ] = package_tuple
+        self.unresolved_dependencies[package_tuple[0]][hash(package_tuple)] = package_tuple
 
-    def set_unresolved_dependencies(
-        self, dependencies: Dict[str, List[Tuple[str, str, str]]]
-    ) -> None:
+    def set_unresolved_dependencies(self, dependencies: Dict[str, List[Tuple[str, str, str]]]) -> None:
         """Set unresolved dependencies - any unresolved dependencies will be overwritten."""
         for dependency_name, dependency_tuples in dependencies.items():
-            self.unresolved_dependencies[dependency_name] = {
-                hash(d): d for d in dependency_tuples
-            }
+            self.unresolved_dependencies[dependency_name] = {hash(d): d for d in dependency_tuples}
 
     def remove_unresolved_dependency(self, package_tuple: Tuple[str, str, str]) -> None:
         """Remove the given unresolved dependency from state."""
@@ -165,29 +148,19 @@ class State:
         """Get a very first unresolved dependency tuple."""
         try:
             unresolved_dependency_name = next(iter(self.unresolved_dependencies))
-            unresolved_dependency_id = next(
-                iter(self.unresolved_dependencies[unresolved_dependency_name])
-            )
-            return self.unresolved_dependencies[unresolved_dependency_name][
-                unresolved_dependency_id
-            ]
+            unresolved_dependency_id = next(iter(self.unresolved_dependencies[unresolved_dependency_name]))
+            return self.unresolved_dependencies[unresolved_dependency_name][unresolved_dependency_id]
         except StopIteration as exc:
-            raise ValueError(
-                f"No unresolved dependency found in state: {self!r}"
-            ) from exc
+            raise ValueError(f"No unresolved dependency found in state: {self!r}") from exc
 
     def get_random_first_unresolved_dependency(self) -> Tuple[str, str, str]:
         """Get a very first unresolved dependency tuple."""
         unresolved_dependency_name = random.choice(list(self.unresolved_dependencies))
         try:
-            unresolved_dependency_id = next(
-                iter(self.unresolved_dependencies[unresolved_dependency_name])
-            )
+            unresolved_dependency_id = next(iter(self.unresolved_dependencies[unresolved_dependency_name]))
             return self.unresolved_dependencies[unresolved_dependency_name][unresolved_dependency_id]
         except StopIteration as exc:
-            raise ValueError(
-                f"No unresolved dependency found in state: {self!r}"
-            ) from exc
+            raise ValueError(f"No unresolved dependency found in state: {self!r}") from exc
 
     @staticmethod
     def _termial_function(n: int) -> int:
@@ -282,9 +255,7 @@ class State:
         else:
             unresolved_dependency_id = random.choice(choices)
 
-        return self.unresolved_dependencies[unresolved_dependency_name][
-            unresolved_dependency_id
-        ]
+        return self.unresolved_dependencies[unresolved_dependency_name][unresolved_dependency_id]
 
     def iter_unresolved_dependencies(self) -> Generator[Tuple[str, str, str], None, None]:
         """Iterate over unresolved dependencies."""
@@ -299,9 +270,7 @@ class State:
         """Return a swallow copy of this state that can be used as a next state."""
         cloned_advised_environment = None
         if self.advised_runtime_environment:
-            cloned_advised_environment = RuntimeEnvironment.from_dict(
-                self.advised_runtime_environment.to_dict()
-            )
+            cloned_advised_environment = RuntimeEnvironment.from_dict(self.advised_runtime_environment.to_dict())
 
         unresolved_dependencies = self.unresolved_dependencies.copy()
         for dependency_name in unresolved_dependencies.keys():
@@ -317,7 +286,7 @@ class State:
             parent=weakref.ref(self),
         )
 
-    def __del__(self):
+    def __del__(self) -> None:
         """Destruct self."""
         # Destruct parts that are not eventually populated to the pipeline product abstraction.
         del self.unresolved_dependencies
