@@ -20,6 +20,9 @@
 from .aicoe import AICoEReleasesStep
 from .cve import CvePenalizationStep
 from .dropout import DropoutStep
+from .tensorflow_avx2 import TensorFlowAVX2Step
+
+# from .mock_score import MockScoreStep
 
 
 # Relative ordering of units is relevant, as the order specifies order
@@ -29,4 +32,6 @@ __all__ = [
     "AICoEReleasesStep",
     "CvePenalizationStep",
     "DropoutStep",
+    "TensorFlowAVX2Step",
+    # "MockScoreStep",
 ]
